@@ -133,6 +133,9 @@ impl<const N: usize> Logic for DDR7FIFO<N> {
                     self.state.d.next = DDR7FIFOState::Idle;
                 }
             }
+            _ => {
+                self.state.d.next = DDR7FIFOState::Booting;
+            }
         }
         self.status.next = bit_cast::<8, 1>(self.front_porch.empty.val().into())
             | (bit_cast::<8, 1>(self.front_porch.full.val().into()) << 1_usize)
