@@ -10,6 +10,7 @@ pub struct MuxedAD7193Simulators {
     pub addr: Signal<In, Bits<3>>,
     pub mux: MuxSlaves<8, 3>,
     pub clock: Signal<In, Clock>,
+    pub reset: Signal<In, Reset>,
     adcs: [AD7193Simulator; 8],
 }
 
@@ -20,6 +21,7 @@ impl MuxedAD7193Simulators {
             mux: Default::default(),
             addr: Default::default(),
             clock: Default::default(),
+            reset: Default::default(),
             adcs: array_init::array_init(|_| AD7193Simulator::new(config)),
         }
     }
@@ -31,6 +33,7 @@ impl Logic for MuxedAD7193Simulators {
         SPIWiresSlave::link(&mut self.wires, &mut self.mux.from_master);
         for i in 0_usize..8 {
             self.adcs[i].clock.next = self.clock.val();
+            self.adcs[i].reset.next = self.reset.val();
             SPIWiresMaster::join(&mut self.mux.to_slaves[i], &mut self.adcs[i].wires);
         }
         self.mux.sel.next = self.addr.val();
@@ -43,6 +46,7 @@ fn test_mux_is_synthesizable() {
     uut.wires.link_connect_dest();
     uut.addr.connect();
     uut.clock.connect();
+    uut.reset.connect();
     uut.connect_all();
     yosys_validate("mux_7193", &generate_verilog(&uut)).unwrap();
 }
