@@ -1,4 +1,5 @@
 use crate::core::prelude::*;
+use crate::core::timing::TimingInfo;
 
 #[derive(Clone, Debug, LogicBlock)]
 pub struct DFF<T: Synth> {
@@ -62,6 +63,15 @@ end
             self._reset_val.verilog()
         ))
     }
+    fn timing(&self) -> Vec<TimingInfo> {
+        vec![TimingInfo {
+            name: "dff".into(),
+            clock: "clock".into(),
+            reset: Some("reset".into()),
+            inputs: vec!["d".into()],
+            outputs: vec!["q".into()],
+        }]
+    }
 }
 
 #[macro_export]
